Range-v3: range/v3/algorithm/reverse_copy.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
reverse_copy.hpp File Reference

## Classes
struct | ranges::v3::reverse_copy_fn

## Typedefs
template<typename I , typename O >
using | ranges::v3::ReverseCopyable = meta::strict_and< BidirectionalIterator< I >, WeaklyIncrementable< O >, IndirectlyCopyable< I, O > >

## Variables
constexpr with_braced_init_args< reverse_copy_fn > | ranges::v3::reverse_copy {}